@@ -1,8 +1,6 @@
-# -*- coding: utf-8 -*-
-
 """A getter for BioGRID."""
 
-from ..utils import Getter, VersionType, get_soup
+from ..utils import Getter, VersionType, find, get_soup
 
 __all__ = [
     "BioGRIDGetter",
@@ -22,8 +20,8 @@ class BioGRIDGetter(Getter):
     def get(self) -> str:
         """Get the latest BioGRID version number."""
         soup = get_soup(URL)
-        manifest = soup.find(id="manifestDesc")
-        header = manifest.find("h2")
+        manifest = find(soup, id="manifestDesc")
+        header = find(manifest, "h2")
         return header.text[len("BioGRID Release ") :]
 
 
