@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 """A getter for SwissLipids."""
 
 import datetime
@@ -12,6 +10,9 @@ __all__ = [
     "SwissLipidGetter",
 ]
 
+# View docs at https://www.swisslipids.org/#/api
+URL = "https://www.swisslipids.org/api/index.php/downloadData"
+
 
 class SwissLipidGetter(Getter):
     """A getter for SwissLipids."""
@@ -22,7 +23,7 @@ class SwissLipidGetter(Getter):
 
     def get(self):
         """Get the latest SwissLipids version number."""
-        res = requests.get("https://www.swisslipids.org/api/downloadData").json()
+        res = requests.get(URL, timeout=15).json()
         record = next(record for record in res if record["file"] == "lipids.tsv")
         return datetime.datetime.strptime(record["date"], "%B %d %Y")
 
